@@ -1,8 +1,8 @@
 #!/usr/bin/perl -w
 
-# STOPPER    Executes a copy if a file contains " nan " in its last line
+# Stopper    Executes a copy if a file contains " nan " in its last line
 # 
-# Version:   0.9  (2001-01-29)
+# Version:   0.91  (2001-02-19)
 #
 # Copyright  (C) 2001 Francesco Poli, <e-frx@libero.it>
 #                     Via Amici 19 50131 Firenze, Italy
@@ -40,7 +40,11 @@ if ( (@ARGV == 1) && ($ARGV[0] eq "--help") )
     "IDLE is the idle time in each period and must be specified in seconds.\n",
     "If IDLE and TRIALS are not specified, default values (1000 and 2) are",
     " used.\n\n",
-    "With the option --help, display this help and exit.\n";
+    "With the option --help, display this help and exit.\n\n",
+    "Stopper version 0.91, Copyright (C) 2001 Francesco Poli\n",
+    "Stopper comes with ABSOLUTELY NO WARRANTY.\n",
+    "This is free software, and you are welcome to redistribute it\n",
+    "under certain conditions; read file `COPYING' for details.\n";
     exit 0;
 }
 elsif ( (@ARGV != 3) && (@ARGV != 5) )
@@ -53,12 +57,12 @@ else
 {
     ($text, $source, $dest, $idle, $trials) = @ARGV;
     # default values of IDLE and TRIALS
-    $idle   = 10   unless $idle;    ########### debug !!
+    $idle   = 1000 unless $idle;
     $trials = 2    unless $trials;
 }
 
 # save TEXT length (in byte)
-$oldlen = `wc -c $text`;
+$oldlen = -s "$text";
 
 $count = 0;
 
@@ -79,7 +83,7 @@ while ( $count < $trials )
     } 
 
     # save TEXT new length 
-    $newlen = `wc -c $text`;
+    $newlen = -s "$text";
 
     # check length changes
     if ( $newlen eq $oldlen )
